function [err]    = obj_fun_IDM_plus(p,dt_data,dt_sim,x,x_dot,xl_rear,xl_rear_dot,s,reset,...
    include_gap_err, include_speed_err, error_measure,...
    frac_gap,frac_speed)
    %   p   = [p1, p2, p3, p4, p5]
    %         [a,  b,  T,  v0, s0]
    
    H           = dt_sim / dt_data;
    i_vec       = 1 : numel(x_dot);
    iH_vec      = 1 : H : i_vec(end);
    
    if dt_sim > dt_data
        x           = x(iH_vec);
        x_dot       = x_dot(iH_vec);
        xl_rear     = xl_rear(iH_vec);
        xl_rear_dot = xl_rear_dot(iH_vec);
        s           = s(iH_vec);
        reset_new   = zeros(numel(iH_vec),1);
        for i = 1 : numel(reset)
            if reset(i) == 1
                idxs            = find(iH_vec >= i);
                idx             = idxs(1);
                reset_new(idx)  = 1;
            end
        end
    end
    
    a_model     = NaN(numel(iH_vec),1);
    v_model     = a_model;
    x_model     = a_model;
    s_model     = a_model;
    
    for i  = 1 : numel(iH_vec) - 1
        % Initiating after reset
        if reset(i) == 1
            a_model(i)	= 0;
            v_model(i)  = x_dot(i);
            x_model(i)  = x(i);
            s_model(i)  = xl_rear(i) - x_model(i);
        end
        
        s_opt           = p(5) + v_model(i).*p(3) + ...
            v_model(i).*(v_model(i) - xl_rear_dot(i)) ./ (2*sqrt(p(1)*p(2)));
        a_model(i)      = p(1) .* min( ...
            1 - (v_model(i)./p(4)) .^4, ...
            1 - (s_opt ./ s_model(i)) .^2);
        
        % Correct for maximum feasible de-/acceleration
        a_min           = -10;
        a_max           = 5.49;
        a_model(i)      = min(a_max, max(a_min, a_model(i)));

        % Update velocity using explicit Euler integration
        v_model(i+1)    = v_model(i) + a_model(i) * dt_sim;
        % Update position via trapezoidal rule as in \cite{Kesting2008}
        x_model(i+1)    = x_model(i) + (v_model(i) + v_model(i+1)) .* ...
            dt_sim./2;
        
        % Update spacing using rule for internal consistency
        s_model(i+1)    = xl_rear(i+1) - x_model(i+1);
    end
        
    err     = compute_error(s, s_model, x_dot, v_model,...
        include_gap_err, include_speed_err, error_measure, ...
        frac_gap, frac_speed);
end











