function [err]    = obj_fun_OVM(p,dt_data,dt_sim,x,x_dot,xl_rear,s,reset,...
    include_gap_err, include_speed_err, error_measure,...
    frac_gap,frac_speed)
    %   p   = [p1, p2, p3, p4]
    %         [a,  v0, s0, T ]
    % As in Treiber, M., & Kesting, A. (2013). Traffic Flow Dynamics.

    H           = dt_sim / dt_data;
    i_vec       = 1 : numel(x_dot);
    iH_vec      = 1 : H : i_vec(end);
    
    if dt_sim > dt_data
        x           = x(iH_vec);
        x_dot       = x_dot(iH_vec);
        xl_rear     = xl_rear(iH_vec);
        s           = s(iH_vec);
        reset_new   = zeros(numel(iH_vec),1);
        for i = 1 : numel(reset)
            if reset(i) == 1
                idxs            = find(iH_vec >= i);
                idx             = idxs(1);
                reset_new(idx)  = 1;
            end
        end
    end
    
    a_model     = NaN(numel(iH_vec),1);
    v_model     = a_model;
    x_model     = a_model;
    s_model     = a_model;
    
    for i  = 1 : numel(iH_vec) - 1
        % Initiating after reset
        if reset(i) == 1
            a_model(i)	= 0;
            v_model(i)  = x_dot(i);
            x_model(i)  = x(i);
            s_model(i)  = xl_rear(i) - x_model(i);
        end
        
%         v_opt           = p(2) * ...
%             ( tanh(s_model(i)/p(3) - p(4)) + tanh(p(4)) ) ./ ...
%             ( 1 + tanh(p(4)) );   
        v_opt           = max(0,min(p(2), (s_model(i)-p(3))/p(4)));
        a_model(i)      = (v_opt - v_model(i)) / (p(2)/p(1));
        
        % Correct for maximum feasible de-/acceleration
        a_min           = -10;
        a_max           = 5.49;
        a_model(i)      = min(a_max, max(a_min, a_model(i)));

        % Update velocity using explicit Euler integration
        v_model(i+1)    = v_model(i) + a_model(i) * dt_sim;
        % Update position via trapezoidal rule as in \cite{Kesting2008}
        x_model(i+1)    = x_model(i) + (v_model(i) + v_model(i+1)) .* ...
            dt_sim./2;
        
        % Update spacing using rule for internal consistency
        s_model(i+1)    = xl_rear(i+1) - x_model(i+1);
    end
    
    err     = compute_error(s, s_model, x_dot, v_model,...
        include_gap_err, include_speed_err, error_measure, ...
        frac_gap, frac_speed);
end











