function    [table_out]     = add_to_timetable(table_current,table_add,Fs,t_thresh)
    % Remove duplicates (keep last time)
    [n, bin]    = histc(datenum(table_add.Time), unique(datenum(table_add.Time)));
    multiple    = find(n > 1);
    index       = find(ismember(bin, multiple));
    rm_index    = index(diff(index)==1);
    table_add(rm_index,:)  = [];
        
    % Find missing data
    tmp_idx_reset   = find(diff(table_add.Time) > seconds(t_thresh));
    tmp_idx_reset   = [0; tmp_idx_reset; size(table_add,1)];
    
    % In case the MobilEye signal is selected, add reset points as 
    % 'missing points' (missing point is added BEFORE new id)
    if max(ismember(fieldnames(table_add),{'obstacle_1_id'}))        
        % Find all discontinuities from changing lead-vehicles
        gap_lead    = diff(table_add.obstacle_1_id);
        gap_lead    = find(gap_lead ~= 0);

        % Add reset indices to total index vector
        tmp_idx_reset   = unique(sort([tmp_idx_reset; gap_lead]));
    end
    
    % For each of the non-missing intervals, retime the signal and
    % write to the final table
    table_out         = timetable();
    for i = 1 : numel(tmp_idx_reset) - 1
        idxs        = tmp_idx_reset(i) + 1 : tmp_idx_reset(i+1);
            
        TT          = sortrows(table_add(idxs,:),'Time','ascend');
        TT          = retime(TT,'Regular','SampleRate',Fs);
        
        % In case there are step variables, avoid NaN at index 1
        stepVars    = find(ismember(TT.Properties.VariableContinuity,{'step'}));
        for iCol = stepVars
            TT.(iCol)(isnan(TT.(iCol)))     = TT.(iCol)(2);
        end
        
        table_out   = [table_out; TT];
    end
    table_add       = table_out;
    
    % Again remove duplicates (keep last time)
    [n, bin]    = histc(datenum(table_add.Time), unique(datenum(table_add.Time)));
    multiple    = find(n > 1);
    index       = find(ismember(bin, multiple));
    rm_index    = index(diff(index)==1);
    table_add(rm_index,:)  = [];
    
    % Synchronize tables
    table_out   = outerjoin(table_current,table_add);
end
