function [AUDI_regimes]   = compute_dependent_vars_regimes(data, dt)
    %% Important quantities
    t_int_min   = 1;                    % [s], Minimum length of interval
    
    %% Find all discontinuities - In find_reset_points.m, a newer version of this code is found
    %   - From missing times due to unusable data
    %   - From changing lead-vehicles
    gap_missing = [1;find(diff(data.Time) > seconds(.11)) + 1];
    gap_lead    = diff(data.ID);
    gap_lead    = unique([1; find((gap_lead ~= 0)) + 1; size(data,1)]);

    % Construct reset idxs
    idx_reset   = sort([gap_missing; gap_lead]);

    % Only keep intervals consisting of more than 30 seconds
    %   30 seconds is arbitrary, any number can be chosen...
    idx_int_min = t_int_min ./ dt;
    d_idx_reset = diff(idx_reset);
    idx_keep    = find(d_idx_reset > idx_int_min);

    % Create new timetable consisting only of suitable intervals
    AUDI_short  = timetable();
    for i = 1 : numel(idx_keep)
        AUDI_short  = [AUDI_short; data( ...
            idx_reset(idx_keep(i)) : idx_reset(idx_keep(i)+1) - 1,:) ];
    end

    % Re-calculate reset idxs
    gap_missing = [1;find(diff(AUDI_short.Time) > seconds(.11)) + 1];
    gap_lead    = diff(AUDI_short.ID);
    gap_lead    = find((gap_lead ~= 0)) + 1;
    idx_reset   = unique(sort([gap_missing; gap_lead]));
    AUDI_short.reset            = zeros(numel(AUDI_short.Time),1);
    AUDI_short.reset(idx_reset) = 1;
    
    %% Calculate remaining variables
    % In get_dependent_vars.m, a newer version of this code is given ...
    
    idx_reset   = [find(AUDI_short.reset == 1); size(AUDI_short,1)];
    x_v         = NaN(numel(AUDI_short.Time),1);
    a_v         = NaN(numel(AUDI_short.Time),1);
    ds_s        = NaN(numel(AUDI_short.Time),1);
    
    tmp_s       = AUDI_short.s;
    tmp_x       = AUDI_short.dist_kal;
    tmp_x_dot   = AUDI_short.speed_kal;

    for i = 1 : numel(idx_reset) - 1
        idxs                = (idx_reset(i):idx_reset(i+1)-1)';

        x_v(idxs)          	= cumtrapz(dt, tmp_x_dot(idxs)) + tmp_x(idxs(1));

        tmp_ds_s            = NaN(numel(idxs),1);
        for j = 2 : numel(idxs) - 1
            tmp_ds_s(j)     = (tmp_s(idxs(j+1)) - tmp_s(idxs(j-1))) ./ (2 * dt);
        end
        tmp_ds_s([1, end])  = tmp_ds_s([2, end-1]);
        ds_s(idxs)          = tmp_ds_s;

        tmp_a_v             = NaN(numel(idxs),1);
        for j = 2 : numel(idxs) - 1
            tmp_a_v(j)      = (tmp_x_dot(idxs(j+1)) - tmp_x_dot(idxs(j-1))) ./ (2 * dt);
        end
        tmp_a_v([1, end])   = tmp_a_v([2, end-1]);
        a_v(idxs)           = tmp_a_v;
    end
    
    AUDI_regimes    = AUDI_short(:,ismember(fieldnames(AUDI_short), ...
        {'speed_kal','s'}));
    AUDI_regimes.Properties.VariableNames   = {'x_dot','s'};
    
    AUDI_regimes.x          = x_v;
    AUDI_regimes.x_ddot 	= a_v;
    AUDI_regimes.s_dot      = ds_s;
end


