function [suitable_times_LC]   = find_suitable_times_LC(CAN,ME,d_marks,...
    effective_duration,t_threshold,d_threshold)
    global sFont figWidth figHeight cmap

    % Constants
    print_figures           = true;

    % Find peaks for the left lane markings
    d_peaks_left            = diff(d_marks.distance_to_left_lane);
    [idx_d_peaks_left,~]    = find(abs(d_peaks_left) >= d_threshold);
    t_peaks_left            = d_marks.Time(idx_d_peaks_left);

    % Find peaks for the right lane markings
    d_peaks_right           = diff(d_marks.distance_to_right_lane);
    [idx_d_peaks_right,~]   = find(abs(d_peaks_right) >= d_threshold);
    t_peaks_right           = d_marks.Time(idx_d_peaks_right);

    % Find peaks, time between peaks and direction of peaks
    %   If peaks are in same direction -> t_peaks_matrix indicates positive
    %   value
    t_peaks_matrix          = NaN(numel(t_peaks_left),numel(t_peaks_right));
    for i = 1 : size(t_peaks_right,1)

        t_peaks_matrix(:,i)     = seconds(abs(t_peaks_left - t_peaks_right(i)));
        t_peaks_matrix(t_peaks_matrix(:,i) == 0,i) = eps;

        tmp_peaks_direction     = sign(d_peaks_left(idx_d_peaks_left)) .* ...
            sign(d_peaks_right(idx_d_peaks_right(i)));
        tmp_peaks_direction(tmp_peaks_direction < 0)    = NaN;
        tmp_LC_direction        = sign(d_peaks_left(idx_d_peaks_left));

        t_peaks_matrix(:,i)     = t_peaks_matrix(:,i) .* ...
            tmp_peaks_direction .* tmp_LC_direction;

    end

    % Find occurances at which both left and right lane-markings change within
    % time-interval defined by t_threshold

    % Find right lane-changes from MobilEye
    [i_LC_left, i_LC_right]     = find(...
        (t_peaks_matrix >= -t_threshold) & (t_peaks_matrix <= 0));
    t_LC_left 	= t_peaks_left(i_LC_left) + ...
        (t_peaks_left(i_LC_left) - t_peaks_right(i_LC_right)) ./ 2;

    % Find left lane changes from MobilEye
    [i_LC_left, i_LC_right]     = find(...
        (t_peaks_matrix <= t_threshold) & (t_peaks_matrix > 0));
    t_LC_right 	= t_peaks_right(i_LC_right) + ...
        (t_peaks_left(i_LC_left) - t_peaks_right(i_LC_right)) ./ 2;

    % Find left lane-changes from indicator signal
    %   t_IS_left   = ON | OFF
    t_IS_left(:,1)  = CAN.Time(diff(CAN.indicator_left_status) == 1);
    t_IS_left(:,2)  = CAN.Time(diff(CAN.indicator_left_status) == -1);

    % Find right lane-changes from indicator signal
    %   t_IS_right  = ON | OFF
    t_IS_right(:,1) = CAN.Time(diff(CAN.indicator_right_status) == 1);
    t_IS_right(:,2) = CAN.Time(diff(CAN.indicator_right_status) == -1);

    % Calculate interval within which lane change effects are visible
    LC              = timetable(CAN.Time, ...
        ones(numel(CAN.Time),1), ...
        ones(numel(CAN.Time),1), ...
        ones(numel(CAN.Time),1), ...
        ones(numel(CAN.Time),1), ...
        'VariableNames',{'LC_left','LC_right',...
        'IS_left','IS_right'});

    for i = 1 : size(t_LC_left,1)
        [~,i_start]	= min(abs(LC.Time - (t_LC_left(i) - seconds(effective_duration))));
        [~,i_end]	= min(abs(LC.Time - (t_LC_left(i) + seconds(effective_duration))));
        LC.LC_left(i_start:i_end)     = 0;
    end
    for i = 1 : size(t_LC_right,1)
        [~,i_start]	= min(abs(LC.Time - (t_LC_right(i) - seconds(effective_duration))));
        [~,i_end] 	= min(abs(LC.Time - (t_LC_right(i) + seconds(effective_duration))));
        LC.LC_right(i_start:i_end)     = 0;
    end
    for i = 1 : size(t_IS_left,1)
        [~,i_start]	= min(abs(LC.Time - (t_IS_left(i,1) - seconds(effective_duration))));
        [~,i_end]   = min(abs(LC.Time - (t_IS_left(i,2) + seconds(effective_duration))));
        LC.IS_left(i_start:i_end)     = 0;
    end
    for i = 1 : size(t_IS_right,1)
        [~,i_start]	= min(abs(LC.Time - (t_IS_right(i,1) - seconds(effective_duration))));
        [~,i_end] 	= min(abs(LC.Time - (t_IS_right(i,2) + seconds(effective_duration))));
        LC.IS_right(i_start:i_end)     = 0;
    end
    
    %%
    if print_figures
        % Set non-flag values to NaN, such that the plot becomes more clear
        tmp_LC  = LC;
        tmp_LC.IS_left(tmp_LC.IS_left == 1)     = NaN;
        tmp_LC.IS_right(tmp_LC.IS_right == 1)   = NaN;
        tmp_LC.LC_left(tmp_LC.LC_left == 1)     = NaN;
        tmp_LC.LC_right(tmp_LC.LC_right == 1)   = NaN;
        
        tmp_CAN = CAN;
        tmp_CAN.indicator_left_status(...
            tmp_CAN.indicator_left_status == 0)     = NaN;
        tmp_CAN.indicator_right_status(...
            tmp_CAN.indicator_right_status == 0)    = NaN;
        
        hFig2 = figure();
        set(hFig2, 'Position', [100 100 figWidth .7*figHeight])
        set(gcf,'Color','white');

        % Add plots to figure
        hold on; grid minor
        plot(CAN.Time,(1-tmp_LC.LC_left) .* 4.5, '*', 'LineWidth',1.5)
        plot(CAN.Time,(1-tmp_LC.LC_right) .* 4.5, '*', 'LineWidth',1.5)
        plot(CAN.Time,(1-tmp_LC.IS_left) .* 4.1, '*', 'LineWidth',1.5)
        plot(CAN.Time,(1-tmp_LC.IS_right) .* 4.1, '*', 'LineWidth',1.5)
        plot(CAN.Time,tmp_CAN.indicator_left_status .* 3.7, '*','LineWidth',1.5)
        plot(CAN.Time,tmp_CAN.indicator_right_status .* 3.7, '*','LineWidth',1.5)
        plot(d_marks.Time,d_marks.distance_to_left_lane ,'LineWidth',1.5)
        plot(d_marks.Time,d_marks.distance_to_right_lane ,'LineWidth',1.5)
        plot(d_marks.Time(1:end-1),diff(d_marks.distance_to_right_lane),'LineWidth',1.5)
  
        % Set figure properties
        ylabel('Distance, m','FontSize',sFont,'FontWeight','normal');
        legend('L Lane-Change Flag','R Lane-Change Flag',...
            'L Indicator Flag','R Indicator Flag',...
            'L Indicator On','R Indicator On',...
            'Dist. Marks Left','Dist. Marks Left',...
            'Actual Lane Change \newline(<0 Right, >0 Left)')
        set(gca,'FontSize',sFont)
        set(gca,'YLim',[-4 4.6])
        
        set(gca,'XLim',[datetime([2018 06 13 07 10 00]), datetime([2018 06 13 07 11 30])])
        datetick('x','HH:MM:ss','keeplimits','keepticks')

        set(zoom(figure(hFig2)),'Motion','horizontal')
        set(pan(figure(hFig2)),'Motion','horizontal')
    end
    
    % Output table
    suitable_times_LC   = LC;
end













