function [data_out]     = select_MobilEye(data,t_start,t_end,Fs)

    % List of selected MobilEye signals
    %   1 - Obstacle longitudinal position, x
    %   2 - Obstacle lateral position, y
    %   3 - Obstacle longitudinal velocity, vx
    %   4 - Obstacle ID
    %   5 - Obstacle CIPV-flag
    %   6 - Obstacle lane
    
    % Constants
    t_thresh            = 2;
    filterWidth_lead    = 9;
    
    obstacle        = timetable();

    %% Load first part of the data, filter signals
    TT              = data.DL004.Advantech_MobilEye.T_mobileye_0x739_raw;
    TT              = TT(:,ismember(fieldnames(TT),{'obstacle_1_pos_x', ...
                        'obstacle_1_pos_y','obstacle_1_relative_velocity_x', ...
                        'obstacle_1_id'}));
                    
    % Find all discontinuities: BEFORE the discontinuity
    %   - From missing times due to unusable data
    %   - From changing lead-vehicles
    gap_missing = find(diff(TT.Time) > seconds(t_thresh));  % BEFORE
    gap_lead    = diff(TT.obstacle_1_id);                   % BEFORE
    gap_lead    = [0; find(gap_lead ~= 0); size(TT,1)];     % BEFORE

    % Add reset indices to total index vector
    tmp_idx_missing   = unique(sort([gap_missing; gap_lead]));

    % Construct reset idxs
    idx_reset   = unique(sort([gap_missing; gap_lead]));
    
    % Filter signals
    for i = 1 : numel(idx_reset) - 1
        idxs    = idx_reset(i) + 1 : idx_reset(i+1);
        TT.obstacle_1_pos_x(idxs)     = movmean(TT.obstacle_1_pos_x(idxs), ...
            [filterWidth_lead, filterWidth_lead]);
    end
       
    % Add filtered signals to timetable
    TT.Properties.VariableContinuity = ...
        {'step','continuous','continuous','continuous'};
    obstacle        = add_to_timetable(obstacle,TT,Fs,t_thresh);

    %% Load and add second part
    TT              = data.DL004.Advantech_MobilEye.T_mobileye_0x73a_raw;
    TT              = TT(:,ismember(fieldnames(TT),{'obstacle_1_cipv_flag',...
                        'obstacle_1_lane'}));
    TT.Properties.VariableContinuity  = {'step','step'};
    obstacle        = add_to_timetable(obstacle,TT,Fs,t_thresh);

    %% Return data
    obstacle.Properties.VariableNames   = {'ID','x','y','vx','lane','cipv'};
    
    obstacle.cipv(isnan(obstacle.cipv)) = 0;
    obstacle.lane(isnan(obstacle.lane)) = 0;
    
    % Return data
	data_out            = obstacle(...
        (obstacle.Time >= t_start) & ...
        (obstacle.Time <= t_end),:...
        );
end
















