function    [p_IDM,costval,exitflag,output] = calibrate_IDM(data_in)
    global options 
    global p_IDM_pub
    global a_range b_range T_range v0_range s0_range
    
    N_param    	= numel(p_IDM_pub);
    FN          = fieldnames(data_in);
    p_IDM       = NaN(numel(FN),N_param);
    costval     = NaN(numel(FN),1);
    exitflag    = NaN(numel(FN),1);
    
    progressbar(0,0)
    for i = 1 : numel(FN)
        progressbar([],0)
        try
            i_cali  = data_in.(FN{i}).calibration_setup.i_cali;
        catch
            i_cali  = [1,size(data_in.(FN{i}).timetab,1)];
        end
        for j = 1 : size(i_cali,1)
            progressbar((i-1)/numel(FN), (j-1)/size(i_cali,1))
            % Acceleration, velocity and position from Kalman velocity
            % Distance-gap and lead vehicle velocity from MobilEye distance-gap
            fun_IDM     = @(p_IDM) obj_fun_IDM(p_IDM, ...
                data_in.(FN{i}).timetab.x(i_cali(j,1) : i_cali(j,2)), ...
                data_in.(FN{i}).timetab.v(i_cali(j,1) : i_cali(j,2)), ...
                data_in.(FN{i}).timetab.xl(i_cali(j,1) : i_cali(j,2)), ...
                data_in.(FN{i}).timetab.vl(i_cali(j,1) : i_cali(j,2)), ...
                data_in.(FN{i}).timetab.s(i_cali(j,1) : i_cali(j,2)), ...
                [1; data_in.(FN{i}).timetab.reset(i_cali(j,1) + 1 : i_cali(j,2))], ...
                data_in.(FN{i}).calibration_setup);

            A           = [];
            b           = [];
            Aeq         = [];
            beq         = [];
            %             [a, b, T, v0, s0]
            lb          = [a_range(1),  b_range(1),  T_range(1),  v0_range(1),  s0_range(1)] .* 1e-4;
            ub          = [8.0,  10e3,  10,  250/3.6,  10];
            nonlcon     = [];

            try
                [p_IDM(i,:,j),costval(i,j),exitflag(i,j),output] = ...
                    fmincon(fun_IDM,p_IDM_pub,A,b,Aeq,beq,lb,ub,nonlcon,options);
                if ~ismember(exitflag(i,j), [0, 1, 2])
                    p_IDM(i,:,j)    = NaN(1,N_param);
                    costval(i,j)    = NaN;
                    exitflag(i,j)   = NaN;
                end
            catch
                p_IDM(i,:,j)	= NaN(1,N_param);
                costval(i,j) 	= NaN;
                exitflag        = NaN;
                output          = NaN;
            end
        end
    end
    progressbar(1,1)
    
    p_IDM(p_IDM == 0) = NaN;
end

    
    
    
    
    
    
    