function [out] = compute_error(s, s_model, x_dot, v_model, ...
    calibration_setup)
    
    include_gap_err     = calibration_setup.include_gap_err;
    include_speed_err   = calibration_setup.include_speed_err;
	error_measure       = calibration_setup.error_measure;
    frac_gap            = calibration_setup.frac_gap;
    frac_speed          = calibration_setup.frac_speed;
    calibration_variable = calibration_setup.calibration_variable;
    
    % Adjust calibration settings according to selected calibration variable
    if strcmpi(calibration_variable,'s')
        include_speed_err   = 0;
    elseif strcmpi(calibration_variable,'v')
        include_gap_err     = 0;
    end % else -> calibration_variable == 'sv' -> do nothing
        
    ds_abs      = (s - s_model);
    ds_rel      = ds_abs ./ s;
    dx_dot_abs  = (x_dot - v_model);
    dx_dot_rel  = dx_dot_abs ./ x_dot;

    % Options:
    %   SSE / RMSE/RMSRE / MAE/MARE

    if strcmpi(error_measure,'SSE')
        %%%%%%%% CORRECT

        out     = ...
            (frac_gap * include_gap_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            sqrt( ...
                ((ds_abs')*ds_abs) ...
            ) + ...
            (frac_speed * include_speed_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            sqrt( ...
                ((dx_dot_abs')*dx_dot_abs) ...
            );
    elseif strcmpi(error_measure,'RMSE')
        %%%%%%%% CORRECT

        out     = ...
            (frac_gap * include_gap_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            sqrt( ...
                1/numel(ds_abs) * ((ds_abs')*ds_abs) ...
            ) + ...
            (frac_speed * include_speed_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            sqrt( ...
                1/numel(dx_dot_abs) * ((dx_dot_abs')*dx_dot_abs) ...
            );
    elseif strcmpi(error_measure,'RMSRE')
        %%%%%%%% CORRECT
        
        out     = ...
            (frac_gap * include_gap_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            sqrt( ...
                1/numel(ds_rel) * ((ds_rel')*ds_rel) ...
            ) + ...
            (frac_speed * include_speed_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            sqrt( ...
                1/numel(dx_dot_rel) * ((dx_dot_rel')*dx_dot_rel) ...
            );
    elseif strcmpi(error_measure,'MAE')
        %%%%%%%% CORRECT

        out     = ...
            (frac_gap * include_gap_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            ( ...
                1/numel(ds_abs) * sum(abs(ds_abs)) ...
            ) + ...
            (frac_speed * include_speed_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            ( ...
                1/numel(dx_dot_abs) * sum(abs(dx_dot_abs)) ...
            );
    elseif strcmpi(error_measure,'MARE')
        %%%%%%%% CORRECT

        out     = ...
            (frac_gap * include_gap_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            ( ...
                1/numel(ds_rel) * sum(abs(ds_rel)) ...
            ) + ...
            (frac_speed * include_speed_err) / ...
            (frac_gap * include_gap_err + frac_speed * include_speed_err) * ...
            ( ...
                1/numel(dx_dot_rel) * sum(abs(dx_dot_rel)) ...
            );
    else
        fprintf('Error: No/incorrect error measure defined. Ending calibration.\n');
    end
end



