function    [data_out]  = find_reset_points(data_in)   
    global dt_data t_int_min 

    t_thresh    = 0.11;
    
    % Find all discontinuities: AT the discontinuity
    %   - From missing times due to unusable data
    %   - From changing lead-vehicles
    gap_missing = [1; find(diff(data_in.Time) > seconds(t_thresh)) + 1; ...
         size(data_in,1) + 1];
    gap_lead    = diff(data_in.ID);
    gap_lead    = find((gap_lead ~= 0)) + 1;
    % Construct reset idxs
    [idx_reset, i_reset_type]   = unique([gap_missing; gap_lead]);
    
    reset_type  = cell(numel(i_reset_type),1);
    % Add reset type information 
    for i = 1 : numel(i_reset_type)
        if i_reset_type(i) <= numel(gap_missing)
            reset_type{i}   = 'hard';
        else
            reset_type{i}   = 'soft';
        end
    end

    % Remove trajects consisting of less than t_int_min seconds
    idx_int_min = t_int_min ./ dt_data;
    d_idx_reset = diff(idx_reset);
    idx_keep    = find(d_idx_reset > idx_int_min);

    % Create new timetable consisting only of suitable intervals
    data_out  = timetable();
    for i = 1 : numel(idx_keep)
        data_out    = [data_out; data_in( ...
            idx_reset(idx_keep(i)) : idx_reset(idx_keep(i)+1) - 1,:) ];
    end

    % Find all discontinuities: AT the discontinuity
    %   - From missing times due to unusable data
    %   - From changing lead-vehicles
    gap_missing = [1; find(diff(data_in.Time) > seconds(t_thresh)) + 1];
    gap_lead    = diff(data_in.ID);
    gap_lead    = find((gap_lead ~= 0)) + 1;
    % Construct reset idxs
    [idx_reset, i_reset_type]   = unique([gap_missing; gap_lead]);
    
    reset_type  = cell(numel(i_reset_type),1);
    % Add reset type information 
    for i = 1 : numel(i_reset_type)
        if i_reset_type(i) <= numel(gap_missing)
            reset_type{i}   = 'hard';
        else
            reset_type{i}   = 'soft';
        end
    end
    
    % Write reset vector
    data_out.reset        	= zeros(numel(data_out.Time),1);
    data_out.reset(idx_reset) = 1;
    data_out.reset_type     = cell(numel(data_out.Time),1);
    data_out.reset_type(idx_reset) = reset_type;

    % Write to final table
    data_out.Properties.VariableContinuity = ...
        {'continuous','continuous','step','step',...
        'step','continuous','continuous','step','step','continuous','continuous',...
        'continuous','continuous','step','step','unset','unset'};
end















