function [data_out] = get_dependent_vars(data_in, base_variable)
    global dt_data 
    
    idx_reset   = [find(data_in.reset == 1); size(data_in,1)];
    v_x         = NaN(numel(data_in.x),1);
    a_x         = NaN(numel(data_in.x),1);
    x_v         = NaN(numel(data_in.x),1);
    a_v         = NaN(numel(data_in.x),1);
    ds_s        = NaN(numel(data_in.x),1);

    for i = 1 : numel(idx_reset) - 1
        idxs            = (idx_reset(i):idx_reset(i+1)-1)';

        %%%%%%%% EGO VEHICLE (base variable 'x') %%%%%%%%
        if strcmpi(base_variable,'x')
            
            v_x(idxs)           = finite_difference(data_in.x(idxs), dt_data);

            tmp_a_x         = NaN(numel(idxs),1);
            for j = 2 : numel(idxs) - 1
    %             tmp_a_x(j)      = (v_x(idxs(j+1)) - v_x(idxs(j-1))) ./ (2 * dt_data);
                tmp_a_x(j)      = (data_in.x(idxs(j+1)) - ...
                    2*data_in.x(idxs(j)) + data_in.x(idxs(j-1))) ./ (dt_data^2);
            end
            tmp_a_x([1, end])   = tmp_a_x([2, end-1]);
            a_x(idxs)           = tmp_a_x;
        
        %%%%%%%% EGO VEHICLE (base variable 'v') %%%%%%%%
        elseif strcmpi(base_variable,'v')
            
            x_v(idxs)       = cumtrapz(dt_data, data_in.v(idxs)) + ...
                data_in.x(idxs(1));
            a_v(idxs)           = finite_difference(data_in.v(idxs), dt_data);

        end
        
        %%%%%%%% LEAD VEHICLE %%%%%%%%
        ds_s(idxs)          = finite_difference(data_in.s(idxs), dt_data);
        
    end
    cols            = ~ismember(fieldnames(data_in), ...
        {'s_dot','x','v','vl','a'});
    data_out        = data_in(:,cols(1:end-3));

    data_out.s_dot  = ds_s;
    if strcmpi(base_variable,'x')
        data_out.x      = data_in.x;
        data_out.v      = v_x;
        data_out.a      = a_x;
    elseif strcmpi(base_variable,'v')
        data_out.x      = x_v;
        data_out.v      = data_in.v;
        data_out.a      = a_v;
    end
    data_out.vl     = data_out.s_dot + data_out.v;
    
    data_out(isnan(data_out.a),:)  = [];
end

