function [out]    = obj_fun_kalman(q,time,speed_can,speed_gps,acc_acl,gap_idxs)

    % Sampling interval
    dt      = 0.1;
    
    % Initiate Q
    q11     = q(1); 
    q22     = q(2); 
    q33     = q(3); 
    q44     = q(4);
    
    % Initiate R
    r11     = (4).^2; %(4).^2; 
    r22     = (0.2320).^2;%(.0948).^2; 
    r33     = (.0191).^2;

    Q   = [q11  0   0       0;
           0    q22 0       0;
           0    0   q33     0;
           0    0   0       q44];
    R   = [r11  0   0;
           0    r22 0;
           0    0   r33];

    % Initiate system dynamics
    A   = [1 dt dt^2/2 0; 0 1 dt 0; 0 0 1 1; 0 0 0 1];
    C   = eye(3);

    % Initiate P, H (= Cp)
    P   = Q;
    H   = [1 0 0 0; 0 1 0 0; 0 0 1 1];
    
    % Initiate output vectors
    v_a_kal     = NaN(size(time));
    x_v_kal     = NaN(size(time));
    x_v_GPS     = NaN(size(time));
    speed_kal   = NaN(size(time));
    
    for j = 1 : numel(gap_idxs) - 1

        % Find required indices
        idxs        = gap_idxs(j) + 1 : gap_idxs(j + 1);

        % Select parts of signals
        v_odo       = speed_can(idxs);
        v_gps       = speed_gps(idxs);
        acc         = acc_acl(idxs);

        % Compute driven distance
        dist_GPS_v  = cumtrapz(dt,v_gps);

        % Initiate state estimation
        x_hat     	= zeros(4,numel(idxs));
        x_hat(:,1)	= [dist_GPS_v(1); v_odo(1); acc(1); 0];

        % Run filter
        for i = 1 : numel(idxs)
            x_hat_time      = A*x_hat(:,i);
            P_time          = A*P*A' + Q;

            K               = P_time * H'/(H*P_time*H' + R);
            y               = C*[dist_GPS_v(i); v_odo(i); acc(i)];

            x_hat(:,i+1)    = x_hat_time + K*(y - H*x_hat_time);
            P               = (eye(4) - K*H)*P_time;
        end
        
        % Write to output vector
        dist_kal(idxs)      = x_hat(1,1:end-1)';
        speed_kal(idxs)     = x_hat(2,1:end-1)';
        acc_kal(idxs)       = x_hat(3,1:end-1)';
    end
    
    % Compute dependent variables ...
    v_a     = NaN(numel(speed_kal),1);
    v_x     = NaN(numel(speed_kal),1);

    v_a(idxs) = cumtrapz(dt,acc_kal(idxs)) + speed_can(idxs(1));
    v_v     = speed_kal;
    
    tmp_v_x         = NaN(numel(idxs),1);
    for j = 2 : numel(idxs) - 1
        tmp_v_x(j)      = (dist_kal(idxs(j+1)) - dist_kal(idxs(j-1))) ./ (2 * dt);
    end
    tmp_v_x([1, end])   = tmp_v_x([2, end-1]);
    v_x(idxs)           = tmp_v_x;
    
    va_vx   = v_a - v_x;
    va_vx   = va_vx(~isnan(va_vx));
    va_vv   = v_a - v_v;
    va_vv   = va_vv(~isnan(va_vv));
    vx_vv   = v_x - v_v;
    vx_vv   = vx_vv(~isnan(vx_vv));

    % Compute mixed RMSE of velocities resulting from all sources
    % Goal is to minimise this value by varying Q
    out     = ...
        sqrt( ...
            1/numel(va_vx) * ((va_vx')*va_vx) ...
        ) + ...
        sqrt( ...
            1/numel(va_vv) * ((va_vv')*va_vv) ...
        ) + ...
        sqrt( ...
            1/numel(vx_vv) * ((vx_vv')*vx_vv) ...
        );
    
end
















