function [p_IDM_out, data_out, varinfo] = ...
    add_variations_synthetic_data(p_IDM_in, data_in, type)
    global calibration_setup dt_data

    FN   = fieldnames(data_in);
    progressbar(0)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Add new trajectories with varying error measures:
    %   'SSE','RMSE','RMSRE','MAE','MARE' 
    if strcmpi('error_measure',type)
        % Define number of variations and varinfo.labels
        N_variations    = 4;
        varinfo.labels          = [repmat({'RMSE'}, numel(FN), 1); ...
            repmat({'RMSRE'}, numel(FN), 1); ...
            repmat({'MAE'}, numel(FN), 1); ...
            repmat({'MARE'}, numel(FN), 1)];
        
        % Adjust parameter matrix
        p_IDM_out       = repmat(p_IDM_in, N_variations, 1);
        for i = 1 : numel(FN)*N_variations
            progressbar((i-1) / (numel(FN)*N_variations))
            % Calculate original data for current iteration
            N_base  = rem(i,numel(FN));
            if N_base == 0; N_base = numel(FN); end
            
            % Duplicate the original data and apply error measure variation 
            fld             = strcat('traject',num2str(i));
            data_out.(fld)  = data_in.(strcat('traject',num2str(N_base)));
            data_out.(fld).calibration_setup.error_measure = varinfo.labels{i};
        end
        
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Add new trajectories with varying calibration-variable:
    %   's' 'sv' 'v'
    elseif strcmpi('calibration_variable',type)
        % Define number of variations and varinfo.labels
        N_variations    = 3;
        varinfo.labels          = [repmat({'s'}, numel(FN), 1); ...
            repmat({'sv'}, numel(FN), 1); ...
            repmat({'v'}, numel(FN), 1)];
        
        % Adjust parameter matrix
        p_IDM_out       = repmat(p_IDM_in, N_variations, 1);
        for i = 1 : numel(FN)*N_variations
            progressbar((i-1) / (numel(FN)*N_variations))
            % Calculate original data for current iteration
            N_base  = rem(i,numel(FN));
            if N_base == 0; N_base = numel(FN); end
            
            % Duplicate the original data and apply error measure variation 
            fld             = strcat('traject',num2str(i));
            data_out.(fld)  = data_in.(strcat('traject',num2str(N_base)));
            data_out.(fld).calibration_setup.calibration_variable = varinfo.labels{i};
        end
        
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Add new trajectories with varying weight:
    %   s-v: 90-10, 75-25, 50-50, 25-75, 10-90
    elseif strcmpi('variable_weight',type)
        % Define number of variations and varinfo.labels
        N_variations    = 5;
        varinfo.labels          = [repmat({'100-0'}, numel(FN), 1); ...
            repmat({'75-25'}, numel(FN), 1); ...
            repmat({'50-50'}, numel(FN), 1); ...
            repmat({'25-75'}, numel(FN), 1); ...
            repmat({'0-100'}, numel(FN), 1)];
        
        % Adjust parameter matrix
        p_IDM_out       = repmat(p_IDM_in, N_variations, 1);
        for i = 1 : numel(FN)*N_variations
            progressbar((i-1) / (numel(FN)*N_variations))
            % Calculate original data for current iteration
            N_base  = rem(i,numel(FN));
            if N_base == 0; N_base = numel(FN); end
            
            % Duplicate the original data and apply error measure variation 
            fld             = strcat('traject',num2str(i));
            data_out.(fld)  = data_in.(strcat('traject',num2str(N_base)));
            
            fracs   = str2double(strsplit(varinfo.labels{i},'-'))/100;
            data_out.(fld).calibration_setup.frac_gap   = fracs(1);
            data_out.(fld).calibration_setup.frac_speed = fracs(2);
            data_out.(fld).calibration_setup.calibration_variable = 'sv';
        end
        
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Add new trajectories with varying length:
    %   Inf 300 250 200 150 100
    elseif strcmpi('length',type)
        % Define number of variations and varinfo.labels
        N_variations    = 9;
        varinfo.labels          = [repmat({'Inf'}, numel(FN), 1); ...
            repmat({'300'}, numel(FN), 1); ...
            repmat({'250'}, numel(FN), 1); ...
            repmat({'200'}, numel(FN), 1); ...
            repmat({'150'}, numel(FN), 1); ...
            repmat({'100'}, numel(FN), 1); ...
            repmat({'50'}, numel(FN), 1); ...
            repmat({'25'}, numel(FN), 1); ...
            repmat({'10'}, numel(FN), 1)];
        
        % Adjust parameter matrix
        p_IDM_out       = repmat(p_IDM_in, N_variations, 1);
        for i = 1 : numel(FN)*N_variations
            progressbar((i-1) / (numel(FN)*N_variations))
            % Calculate original data for current iteration
            N_base  = rem(i,numel(FN));
            if N_base == 0; N_base = numel(FN); end
            
            % Duplicate the original data and apply error measure variation 
            fld             = strcat('traject',num2str(i));
            data_out.(fld)  = data_in.(strcat('traject',num2str(N_base)));

            data_out.(fld).calibration_setup.cali_length = str2double(varinfo.labels{i}) / dt_data;
            
            n        	= 100;          % [-], Sliding window step-size
            n_crit  	= 250;          % [s*dt], Critical distance to reset-point
            data_out.(fld) = find_calibration_points(data_out.(fld), n, n_crit);
        end
        j   = 0;
        for i = 1 : numel(FN) : numel(FN)*N_variations
            j = j + 1;
            fld     	= strcat('traject',num2str(i));
            varinfo.times(j,1)  = {data_out.(fld).calibration_setup.t_cali};
        end
            
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Add new trajectories with varying length:
    %   Inf 300 250 200 150 100
    elseif strcmpi('length2',type)
        % Define number of variations and varinfo.labels
        N_variations    = 3;
        varinfo.labels          = [repmat({'50'}, numel(FN), 1); ...
            repmat({'25'}, numel(FN), 1); ...
            repmat({'10'}, numel(FN), 1)];
        
        % Adjust parameter matrix
        p_IDM_out       = repmat(p_IDM_in, N_variations, 1);
        for i = 1 : numel(FN)*N_variations
            progressbar((i-1) / (numel(FN)*N_variations))
            % Calculate original data for current iteration
            N_base  = rem(i,numel(FN));
            if N_base == 0; N_base = numel(FN); end
            
            % Duplicate the original data and apply error measure variation 
            fld             = strcat('traject',num2str(i));
            data_out.(fld)  = data_in.(strcat('traject',num2str(N_base)));

            data_out.(fld).calibration_setup.cali_length = str2double(varinfo.labels{i}) / dt_data;
            
            n        	= 100;          % [-], Sliding window step-size
            n_crit  	= 250;          % [s*dt], Critical distance to reset-point
            data_out.(fld) = find_calibration_points(data_out.(fld), n, n_crit);
        end
        j   = 0;
        for i = 1 : numel(FN) : numel(FN)*N_variations
            j = j + 1;
            fld     	= strcat('traject',num2str(i));
            varinfo.times(j,1)  = {data_out.(fld).calibration_setup.t_cali};
        end
           
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Add new noisy (/biased) trajectories
    %   N(0,0.05)
    elseif strcmpi('noise_FL',type) || strcmpi('noise_L',type)
        if strcmpi('noise_FL',type)
            type_label  = 'FL';
        else
            type_label  = 'L';
        end
        
        % Define number of variations and varinfo.labels
        N_variations    = 5;
        noise_mean      = [ones(numel(FN), 1) .* 0; ...
            ones(numel(FN), 1) .* 0; ...
            ones(numel(FN), 1) .* 0; ...
            ones(numel(FN), 1) .* 0; ...
            ones(numel(FN), 1) .* 0];
        noise_variance  = [ones(numel(FN), 1) .* 0.1; ...
            ones(numel(FN), 1) .* 0.05; ...
            ones(numel(FN), 1) .* 0.01; ...
            ones(numel(FN), 1) .* 0.001; ...
            ones(numel(FN), 1) .* 0];
        varinfo.labels          = ...
            regexprep(cellstr(strcat(num2str(noise_variance))),' +',' ');
        calinfo_labels          = ...
            regexprep(cellstr(strcat(num2str(noise_mean),'-',...
            num2str(noise_variance))),' +','');
        
        % Adjust parameter matrix
        p_IDM_out       = repmat(p_IDM_in, N_variations, 1);
        for i = 1 : numel(FN)*N_variations
            progressbar((i-1) / (numel(FN)*N_variations))
            % Calculate original data for current iteration
            N_base  = rem(i,numel(FN));
            if N_base == 0; N_base = numel(FN); end
            
            % Duplicate the original data and apply error measure variation 
            fld             = strcat('traject',num2str(i));
            data_out.(fld)  = data_in.(strcat('traject',num2str(N_base)));            
            
            % Add noise to follower trajectory
            % https://nl.mathworks.com/help/matlab/math/random-numbers-with-specific-mean-and-variance.html
            if strcmpi('noise_FL',type)
                if strcmpi(calibration_setup.base_variable,'x')
                    data_out.(fld).timetab.x = data_out.(fld).timetab.x + ...
                        sqrt(noise_variance(i)).*randn(size(data_out.(fld).timetab.x)) + ...
                        noise_mean(i);
                elseif strcmpi(calibration_setup.base_variable,'v')
                    data_out.(fld).timetab.v = data_out.(fld).timetab.v + ...
                        sqrt(noise_variance(i)).*randn(size(data_out.(fld).timetab.v)) + ...
                        noise_mean(i);
                end
            end
            
            % Add noise to leader trajectory (measured distance-gap)
            if strcmpi('noise_FL',type) || strcmpi('noise_L',type)
                data_out.(fld).timetab.s = data_out.(fld).timetab.s + ...
                    sqrt(noise_variance(i)).*randn(size(data_out.(fld).timetab.s)) + ...
                    noise_mean(i);
            end
            
            data_out.(fld).calibration_setup.noise_type = type_label;
            data_out.(fld).calibration_setup.noise      = calinfo_labels{i};
            
            % Re-calculate dependent variables
            if noise_variance(i) > 0
                data_out.(fld).timetab = get_dependent_vars(data_out.(fld).timetab, ...
                    calibration_setup.base_variable);
            end
        end
        
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Add new trajectories with varying reset times:
    %   50, 25, 10, 1, 0.1
    elseif strcmpi('reset',type)
        % Define number of variations and varinfo.labels
        N_variations    = 6;
        varinfo.labels          = [repmat({'1000'}, numel(FN), 1); ...
            repmat({'50'}, numel(FN), 1); ...
            repmat({'25'}, numel(FN), 1); ...
            repmat({'10'}, numel(FN), 1); ...
            repmat({'1'}, numel(FN), 1); ...
            repmat({'0.2'}, numel(FN), 1); ...
            ... repmat({'0.1'}, numel(FN), 1)
            ];
        
        % Adjust parameter matrix
        p_IDM_out       = repmat(p_IDM_in, N_variations, 1);
        for i = 1 : numel(FN)*N_variations
            progressbar((i-1) / (numel(FN)*N_variations))
            % Calculate original data for current iteration
            N_base  = rem(i,numel(FN));
            if N_base == 0; N_base = numel(FN); end
            
            % Duplicate the original data
            fld             = strcat('traject',num2str(i));
            data_out.(fld)  = data_in.(strcat('traject',num2str(N_base)));
            
            % Apply reset time to new data
            t_reset         = str2double(varinfo.labels{i});
            data_out.(fld).calibration_setup.t_reset ...
                            = t_reset;
            
            reset_idxs      = [find(data_out.(fld).timetab.reset == 1); 
                numel(data_out.(fld).timetab.reset)+1];
            i_reset         = max(1,t_reset / dt_data);
            for j = 1 : numel(reset_idxs) - 1
                idxs        = reset_idxs(j) : reset_idxs(j+1) - 1;
                data_out.(fld).timetab.reset(idxs(1) : i_reset : idxs(end)) = 1;
            end
        end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Do nothing in case nothing is requested, or do nothing if an
    % incorrect input is provided
    else 
        fprintf('No (valid) variation selected or required. Returning original signals.\n')
        pause(.5)
        varinfo.labels      = repmat({'none'}, numel(FN), 1);
        p_IDM_out   = p_IDM_in;
        data_out    = data_in;
    end
    
    progressbar(1)
end




