function [data_out] = find_calibration_points(data_in, n_step, n_crit)
    
    % Initiate vectors
    i_reset     = find(data_in.timetab.reset == 1);
    n_width     = data_in.calibration_setup.cali_length;
    N           = size(data_in.timetab,1);
    time_vec    = data_in.timetab.Time;

    % If no trajectory length specified, select first and last indices ...
    %       ... and calibrate on middle time
    if n_width == Inf
        i_cali_range    = [1, size(data_in.timetab,1)];
        t_cali          = data_in.timetab.Time(round(numel(data_in.timetab.Time)/2));
    else % If trajectory length is shorter than complete length
        j           = 1;
        for i = 1 : n_step : N
            bool_val    = 1;
            for m = 1 : numel(i_reset)
                % Check if right interval bound is in right critical interval
                bool_val    = bool_val * ...
                    min(~ismember( i_reset(m) : i_reset(m) + n_crit, i + n_width/2 ));

                % Check if left interval bound is in left critical interval
                bool_val    = bool_val * ...
                    min(~ismember( i_reset(m) - n_crit : i_reset(m), i - n_width/2 ));
            end
            % Check if left interval bound is smaller than 0
            bool_val    = bool_val * (i - n_width/2 > 0);

            % Check if right interval bound is larger than length
            % of data
            bool_val    = bool_val * (i + n_width/2 < N);

            % Center index
            i_cali_center(j)    = i * bool_val;

            % Center time
            if i_cali_center(j) ~= 0
                i_cali_range(j,:)	= i_cali_center(j) + [-n_width/2, n_width/2];
                t_cali(j)           = time_vec(i);
                j                   = j + 1;
            end
        end
    end

    % Write calibratino indices and times to final table
    data_in.calibration_setup.i_cali    = i_cali_range;
    data_in.calibration_setup.t_cali    = t_cali';
    
    data_out   = data_in;
end





