function [] = ...
    plot_length_variation(data_syn, p_cali, p_variations, p_choice, ...
    p_names, varinfo, model, dataset, varargin)
    global sFont figWidth_panel figHeight_panel
    
    % Initiate structure for excitation plots
    varinfo.a_range   = cell(size(varinfo.labels));
    varinfo.v_range   = cell(size(varinfo.labels));
    varinfo.vl_range  = cell(size(varinfo.labels));

    %% Compute error of parameter estimates
    if strcmpi(p_choice,'rel')
        p_err   = (p_cali - p_variations) ./ p_variations;
        ysca    = 'linear';
        ylab    = '$$(\beta_i^*-\hat{\beta_i})/\hat{\beta_i}$$';
    elseif strcmpi(p_choice,'absrel')
        p_err    = abs((p_cali - p_variations) ./ p_variations);
        ysca     = 'log';
        ylab    = '$$|(\hat{\beta_i} - \beta_i^*) / \beta_i^*|$$';
    end

    labels_unique   = sort(unique(str2double(varinfo.labels)),'descend');

    tmp_p_values    = [];
    tmp_p_labels    = [];

    times_all   = data_syn.traject1.timetab.Time;
    
    %% Run performance over time, one plot per length
    
    for i = numel(labels_unique)
        % Get parameter errors for current length
        tmp_p_curr  = p_err(strcmpi(varinfo.labels,num2str(labels_unique(i))),:,:);
        p_curr      = permute(tmp_p_curr,[3,1,2]);
        times       = varinfo.times{i};
        p_curr      = p_curr(1:numel(times),:,:);   % Only keep valid p 
        
        hFig    = figure();
        set(hFig, 'Position', [100 100 .5*figWidth_panel 1.4*figHeight_panel])
        set(gcf,'Color','white');
        
        p = panel();
        p.pack('v',{1/6 5/6});
            
        p.margin        = [17 7 5 7];

        p(1).pack(1,1);
        p(1).fontsize  	= sFont;
        p(1).fontweight	= 'normal';
        p(1).margin   	= [0 0 0 0];  	% Outside
        p(1).de.margin  = 0;            % Internal

        p(2).pack(size(p_err,2),1);
        p(2).fontsize  	= sFont;
        p(2).fontweight	= 'normal';
        p(2).margin   	= [0 0 0 12];  	% Outside
        p(2).de.margin  = 2;            % Internal

        times_ref       = [max( times_all(round(numel(times_all)/2)) - seconds(labels_unique(i)/2), min(times_all)),
            min( times_all(round(numel(times_all)/2)) + seconds(labels_unique(i)/2), max(times_all))];
        
        p(1,1,1).select();
        hold on; grid minor;
        plot(data_syn.traject1.timetab.Time, ...
            data_syn.traject1.timetab.v, 'LineWidth', 1.5)
        plot(times_ref, ones(2,1) * max(data_syn.traject1.timetab.v), ...
            '-k', 'LineWidth', 3);
        
        set(gca,'FontSize',sFont)
        set(gca,'XTickLabels',[])
        ylabel('Velocity, m/s','FontSize',9,'FontWeight','normal','Interpreter','none');
        lgnd1   = legend('$$v_i$$',char(strcat({'Reference: '},num2str(labels_unique(i)),{' s'})), ...
            'Interpreter','Latex', 'Orientation', ...
            'Horizontal','Location','SouthWest', 'Units','Normalized');
        
        if strcmpi(dataset,'OSC')
            set(gca,'YTick',0:4:40)
        end
        
        for j = 1 : size(p_err,2)
            p(2,j,1).select();
            hold on; grid minor;
            
            % [1, trajectories, parameter]
            plot(times, prctile(p_curr(:,:,j),25,2), '-', 'LineWidth', 1.5)
            plot(times, nanmedian(p_curr(:,:,j),2), '-', 'LineWidth', 1.5)
            plot(times, prctile(p_curr(:,:,j),75,2), '-', 'LineWidth', 1.5)
            ylabel(char(strcat('$$',p_names(j),'$$')),'Interpreter','Latex',...
                'Rotation',70)
            if j == 1
                lgnd = legend('25-th pct.','Median','75-th pct.', ...
                    'Orientation', 'Horizontal','Location','NorthWest',...
                    'Units','Normalized');
                lgnd.ItemTokenSize      = [15 18];
                title(ylab,'FontSize',sFont,'FontWeight','normal','Interpreter','Latex');
            end
            set(gca,'FontSize',9)
            set(gca,'YScale',ysca)
            set(gca,'YTick', 10.^(-16:2:0))
            if strcmpi(dataset,'OSC')
                xmin_time   = datetime([2018 06 13 10 54 30]);
                xmax_time   = datetime([2018 06 13 10 57 30]);
                set(gca,'XTick',([xmin_time:minutes(1):xmax_time]))
            end
            
            if j ~= size(p_err,2)
                set(gca,'XTickLabels',[])
            end
        end
                
        allAxesInFigure = findall(hFig,'type','axes');
        linkaxes(allAxesInFigure,'x')
        set(allAxesInFigure,'XLim',[min(data_syn.traject1.timetab.Time), ...
            max(data_syn.traject1.timetab.Time)])
        
        linkaxes(allAxesInFigure(1:end-1),'y')
        datetick('x','HH:MM','keeplimits','keepticks')
        
        if strcmpi(dataset, 'OSC')
            set(allAxesInFigure,'XLim',[xmin_time xmax_time])
            datetick('x','HH:MM:ss','keeplimits','keepticks')
            p.margin        = [17 7 7 5];
        end
        
        % Change legend position
        lgnd1.Position([1,2])   = [0.2413, 0.9312];
        lgnd.Position([1,2])    = [0.2079, 0.7354];
    end

    %% Compute performance versus excitation 
    
    FN_data     = fieldnames(data_syn);
    for i = 1 : numel(varinfo.labels)
        % Get current traject number
        N_traj  = rem(i,numel(FN_data));
        if N_traj == 0; N_traj = numel(FN_data); end
        N_var   = ceil(i/numel(FN_data));
        
        % Get all calibration times for current variation (labels)
        times           = varinfo.times{N_var};
        length_current  = str2double(varinfo.labels{i});
        
        % Write min/max observed values to matrix
        a_range         = NaN(numel(times),3); 
        v_range         = NaN(numel(times),3); 
        vl_range        = NaN(numel(times),3); 
        for j = 1 : numel(times)
            % Min/max idxs in time-vector
            [~,i_min] 	= min(abs(datenum(times_all) - ...
                datenum(times(j) - seconds(length_current/2) )));
            [~,i_max] 	= min(abs(datenum(times_all) - ...
                datenum(times(j) + seconds(length_current/2) )));
            
            % Get resulting min/max values
            a_range(j,1:2)  = [min(data_syn.(FN_data{j}).timetab.a(i_min:i_max)), ...
                max(data_syn.(FN_data{j}).timetab.a(i_min:i_max))];
            a_range(j,3)    = a_range(j,2) - a_range(j,1);
            v_range(j,1:2) 	= [min(data_syn.(FN_data{j}).timetab.v(i_min:i_max)), ...
                max(data_syn.(FN_data{j}).timetab.v(i_min:i_max))];
            v_range(j,3)    = v_range(j,2) - v_range(j,1);
            vl_range(j,1:2)	= [min(data_syn.(FN_data{j}).timetab.vl(i_min:i_max)), ...
                max(data_syn.(FN_data{j}).timetab.vl(i_min:i_max))];
            vl_range(j,3)    = vl_range(j,2) - vl_range(j,1);
        end
        % Write to struct
        varinfo.a_range{i}  = a_range;
        varinfo.v_range{i}  = v_range;
        varinfo.vl_range{i} = vl_range;
        clear a_range v_range vl_range
    end
    
    %% Plot performance versus excitation 

        % Find all combinations a_range and p_err
        if strcmpi(model,'IDM')
            length_desired  = 10;
        else %if model == ACC
            length_desired  = 10;
        end
        idxs            = find(str2double(varinfo.labels) == length_desired);
        
        % Select desied results
        num_times       = numel(varinfo.a_range{idxs(1)}(:,3));
        a_range_vec     = [];
        a_min_vec       = [];
        a_max_vec       = [];
        v_range_vec     = [];
        v_avg_vec       = [];
        vl_range_vec    = [];
        p_err_vec       = [];
        for i = 1 : numel(idxs)     % idx(i) is a trajectory
            a_range_vec     = [a_range_vec; varinfo.a_range{idxs(i),1}(:,3)];
            a_min_vec       = [a_min_vec; varinfo.a_range{idxs(i),1}(:,1)];
            a_max_vec       = [a_max_vec; varinfo.a_range{idxs(i),1}(:,2)];
            v_range_vec     = [v_range_vec; varinfo.v_range{idxs(i),1}(:,3)];
            v_avg_vec       = [v_avg_vec; mean(varinfo.v_range{idxs(i),1}(:,1:2),2)];
            vl_range_vec    = [vl_range_vec; varinfo.vl_range{idxs(i),1}(:,3)];
            p_err_vec       = [p_err_vec; ...
                permute(p_err(idxs(i),:,1:num_times), [3,2,1])];
        end
        
        %% Create box-plots
        %   Note: the script first creates box-plots from which the mean,
        %   25th- and 75th-percentile values are extracted. This is much
        %   faster than computing all these values separately.
        % [a, v, vl]
        N_vec               = [.5, 1, 1];
        N_vars              = size(p_err,2);
        ranges.a_range      = round(a_range_vec./N_vec(1),0).*N_vec(1);
        ranges.v_range      = round(v_range_vec./N_vec(2),0).*N_vec(2);
        ranges.vl_range     = round(vl_range_vec./N_vec(3),0).*N_vec(3);
        FN_ranges           = fieldnames(ranges);
        range_titles        = {'a-range','v-range','vl-range'};
        boxplot_width       = [0.05, 0.5, 0.5]*2;
        
        hFig3    = figure();
        set(hFig3, 'Position', [100 100 figWidth_panel 3*figHeight_panel])
        set(gcf,'Color','white');

        p3 = panel();
        p3.pack(N_vars,3);
        p3.fontsize  	= sFont;
        p3.fontweight	= 'normal';
        
        clear hAx
        for i = 1 : numel(FN_ranges)
            range_current    = ranges.(FN_ranges{i}); 
           
            for j = 1 : N_vars
                hAx(j,i) = p3(j,i).select();
                hold on; grid minor;
                
                boxplot(p_err_vec(:,j),range_current, 'Positions',range_current, ...
                    'Labels',range_current,'Widths',boxplot_width(i))

                xtickangle(90) 
                set(gca,'YScale','Log')
                set(gca,'XTick',0:boxplot_width(i)*2:100)
                set(gca,'YTick',10.^(-16:2:0))
                if i == 2
                    title(char(strcat('$$',p_names(j),'$$')),'Interpreter','Latex',...
                        'FontWeight','Normal')
                end
                if i ~= 1
                    set(gca,'YTickLabels',[])
                end
                if j == ceil(N_vars/2) && i == 1
                    ylabel(ylab,'Interpreter','Latex')
                end
                if j < N_vars
                    set(gca,'XTickLabels',[])
                else
                    set(gca,'XTickLabels',0:boxplot_width(i)*2:100)
                    xlabel(range_titles{i},'FontWeight','Normal')
                end
            end
        end
        set(hAx,'YLim',[min(p_err_vec(:)) max([hAx.YLim])])
        
        p3.margin   	= [16 13 3 5];  	% Outside
        p3.de.margin    = 3;            % Internal
        p3.de.margintop = 5;            % Internal
        for j = 1 : 3 
            linkaxes(hAx(N_vars*(j-1)+1 : N_vars*j),'x')
        end
        
        %% Plot landscape performance a_min/a_max
        load('CustomMap', '-mat');
        
        % Uncomment the desired x and y plot values ...
        tmp_N = 0.4;
%         tmp_a_min    	= round(a_min_vec./N_vec(1),0).*N_vec(1);
%         tmp_a_max       = round(a_max_vec./N_vec(1),0).*N_vec(1);
        tmp_a_min    	= round((a_min_vec)./tmp_N,0).*tmp_N;
%         tmp_a_min       = round((a_max_vec)./tmp_N,0).*tmp_N;
%         tmp_a_max       = round((v_avg_vec)./1,0).*1;
        tmp_a_max       = round((a_max_vec)./tmp_N,0).*tmp_N;
        amin_max_range  = regexprep(cellstr(strcat(num2str(tmp_a_min), ...
            '/',num2str(tmp_a_max))),' +','');
        
        % Select proper labels
%         xlabl           = '$$a_{max}, m/s^2$$';
        xlabl           = '$$a_{max}, m/s^2$$';
        ylabl           = '$$a_{min}, m/s^2$$';
        
        % Find ranges and parameter calibration errors
        FN_dataset      = {'CF','OSC','SG1','SG2'};
        fileName    = char(strcat({'./Data/a_min - a_max - '},model,{' - '},dataset,'.mat'));
        save(fileName, 'p_err_vec', 'amin_max_range')
        try
            for i = find(~strcmpi(FN_dataset,dataset))
                data_load = load(char(strcat({'./Data/a_min - a_max - '}, ...
                    model,{' - '},FN_dataset{i},'.mat')));
                amin_max_range  = [amin_max_range; data_load.amin_max_range];
                p_err_vec       = [p_err_vec; data_load.p_err_vec];
            end
        end
        
        % Plot actual figure
        hFig4    = figure();
        set(hFig4, 'Position', [100 100 .5*figWidth_panel 2*figHeight_panel])
        set(gcf,'Color','white');

        p4 = panel();
        p4.pack(N_vars,1);
        p4.fontsize  	= sFont;
        p4.fontweight	= 'normal';
        
        hFig5    = figure();
        set(hFig5, 'Position', [100 100 .5*figWidth_panel .7*figHeight_panel])
        set(gcf,'Color','white');

        p5 = panel();
        p5.pack(1,1);
        p5.fontsize  	= sFont;
        p5.fontweight	= 'normal';
        
        clear hAx hAx2
        hFig = figure();
        for i = 1 : size(p_err_vec,2)
            figure(hFig)
            subplot(size(p_err_vec,2),1,i)
            boxplot(p_err_vec(:,i),amin_max_range)
            
            % Extract median values
            meds    = [];
            loc     = [];
            h       = findobj(gca,'tag','Median');
            for k = 1 : numel(h)
                meds(k)     = h(k).YData(1);
                loc(k)      = mean(h(k).XData);
            end
            [~,idx_sort]    = sort(loc);
            meds_sort       = meds(idx_sort);
            ticks           = get(gca,'XTickLabels');
            tmp_ticks_num   = split(ticks,'/');
            ticks_num       = reshape(str2double(tmp_ticks_num(:)),...
                [numel(tmp_ticks_num)/2,2]);
            
            % Create matrix for imagesc
            p_err_mat               = diag(meds_sort);
            [a_max_unique,~,ic2]	= unique(ticks_num(:,2));
            [a_min_unique,~,ic1]	= unique(ticks_num(:,1));
            p_err_mat               = NaN(max(ic1),max(ic2));
            for j = 1 : numel(ic2)
                p_err_mat(ic1(j),ic2(j))  = meds_sort(j);
            end
            p_err_mat(isnan(p_err_mat)) = Inf;
            
            % Create excitation landscape using imagesc
            figure(hFig4)
            hAx(i) = p4(i,1).select();
            hold on
            imagesc(a_max_unique,a_min_unique,p_err_mat)
            plot([-10,100],[0,0],'k--','LineWidth',.5)
            plot([0,0],[-10,100],'k--','LineWidth',.5)
            set(gca,'colorscale','log')

            title(char(strcat('$$',p_names(i),'$$')),'Interpreter','Latex',...
                'FontWeight','Normal')
            if i == ceil(N_vars/2)
                ylabel(ylabl,'FontWeight','Normal',...
                    'Interpreter','Latex')
            end
            if i < N_vars
                set(gca,'XTickLabels',[])
            else
                xlabel(xlabl,'FontWeight','Normal',...
                    'Interpreter','Latex')
            end
            
            colorbar
            colormap(mymap)
            hcb = colorbar;
            colorTitleHandle = get(hcb,'Title');
            titleString = '$$|\mathcal{F}|$$';
            set(colorTitleHandle,'Interpreter','latex','String',titleString);
            set(hcb,'Ticks',10.^[-10:1:0])
            set(hcb,'TickLabels',cellstr(num2str(round(log10(hcb.Ticks(:))), '10^{%d}')))
        end
        
        close(hFig)
        
        % Set figure properties
        set(hAx,'CLim', [min([hAx.CLim]), max([hAx.CLim])])
        set(hAx2,'CLim', [min([hAx.CLim]), max([hAx.CLim])])
        set(hAx,'XLim', [min(a_max_unique)-tmp_N(1), max(a_max_unique)+tmp_N(1)])
%         set(hAx,'XLim', [min(a_max_unique)-1, max(a_max_unique)+1])
        set(hAx2,'XLim', [min(a_max_unique)-tmp_N(1), max(a_max_unique)+tmp_N(1)])
%         set(hAx2,'XLim', [min(a_max_unique)-1, max(a_max_unique)+1])
        set(hAx,'YLim', [min(a_min_unique)-tmp_N(1), max(a_min_unique)+tmp_N(1)])
        set(hAx2,'YLim', [min(a_min_unique)-tmp_N(1), max(a_min_unique)+tmp_N(1)])
        
        p4.margin   	= [13 11 18 5];  	% Outside
        p4.de.margin    = 1;            % Internal
        p4.de.margintop = 5;            % Internal
        
        p5.margin   	= [13 11 18 5];  	% Outside
        p5.de.margin    = 1;            % Internal
        p5.de.margintop = 5;            % Internal
                
end























