function [] = plot_noise_variation(data_original, data_variations, p, labels)
    global figWidth figHeight sFont cmap
    
    % Compute number of variations, find 0.2 seconds
    FN_original     = fieldnames(data_original);
    FN_variations   = fieldnames(data_variations);
    N_subplots      = numel(FN_variations) / numel(FN_original);
    
    % Find index max and min sampling interval
    i_int_max       = 1;
    i_int_min       = numel(FN_original) * (N_subplots - 1) + i_int_max;

    data_noise_max  = data_variations.(FN_variations{i_int_max});
    tmp_data_max.traject1   = data_noise_max;
    data_noise_min  = data_variations.(FN_variations{i_int_min});
    tmp_data_min.traject1   = data_noise_min;

    % Calibrate model to noisy data
    [p_ACC_max,~,~,~] 	= calibrate_ACC(tmp_data_max);
    [p_ACC_min,~,~,~] 	= calibrate_ACC(tmp_data_min);
    clear tmp_data_*

    [data_noise_max.timetab.a_model, data_noise_max.timetab.v_model, ...
        data_noise_max.timetab.x_model, data_noise_max.timetab.s_model,~] = ...
        get_model_trajectories_ACC(p_ACC_max, ...
        data_noise_max.timetab.x, ...
        data_noise_max.timetab.v, ...
        data_noise_max.timetab.xl, ...
        data_noise_max.timetab.vl, ...
        data_noise_max.timetab.s, ...
        data_noise_max.timetab.reset);

    [data_noise_min.timetab.a_model, data_noise_min.timetab.v_model, ...
        data_noise_min.timetab.x_model, data_noise_min.timetab.s_model,~] = ...
        get_model_trajectories_ACC(p_ACC_min, ...
        data_noise_min.timetab.x, ...
        data_noise_min.timetab.v, ...
        data_noise_min.timetab.xl, ...
        data_noise_min.timetab.vl, ...
        data_noise_min.timetab.s, ...
        data_noise_min.timetab.reset);
    
    %% Plot
    hFig3 = figure();
    set(hFig3, 'Position', [100 100 figWidth figHeight])
    set(gcf,'Color','white');
    
    figure(hFig3)
    sp1     = subplot(3,1,1);
    hold on; grid minor
    plot(data_noise_max.timetab.Time, data_noise_max.timetab.x, 'LineWidth', 1.5)
    plot(data_noise_max.timetab.Time, data_noise_max.timetab.x_model, 'LineWidth', 1.5)
    plot(data_noise_min.timetab.Time, data_noise_min.timetab.x_model,'--', 'LineWidth', 1.5)

    title(''); 
    ylabel('Position, m','FontSize',sFont,'FontWeight','normal');
    legend('Noisy data','Calibrated parameters','Original parameters')
    set(gca,'FontSize',sFont)

    
    
    sp2     = subplot(3,1,2);
    hold on; grid minor
    plot(data_noise_max.timetab.Time, data_noise_max.timetab.v, 'LineWidth', 1.5)
    plot(data_noise_max.timetab.Time, data_noise_max.timetab.v_model, 'LineWidth', 1.5)
    plot(data_noise_min.timetab.Time, data_noise_min.timetab.v_model,'--', 'LineWidth', 1.5)

    title(''); 
    ylabel('Velocity, m/s','FontSize',sFont,'FontWeight','normal');
    legend('Noisy data','Calibrated parameters','Original parameters')
    set(gca,'FontSize',sFont)

    
    
    sp3     = subplot(3,1,3);
    hold on; grid minor
    plot(data_noise_max.timetab.Time, data_noise_max.timetab.a, 'LineWidth', 1.5)
    plot(data_noise_max.timetab.Time, data_noise_max.timetab.a_model, 'LineWidth', 1.5)
    plot(data_noise_min.timetab.Time, data_noise_min.timetab.a_model,'--','LineWidth', 1.5)

    title(''); 
    ylabel('Acceleration, m/s^2','FontSize',sFont,'FontWeight','normal');
    legend('Noisy data','Calibrated parameters','Original parameters')
    set(gca,'FontSize',sFont)

    linkaxes([sp1 sp2 sp3], 'x')
end