function [] = plot_variations(data_original, data_variations, N_plots, ...
    type, labels)
    global sFont figWidth figHeight cmap

    % Compute number of subplots needed
    FN_original     = fieldnames(data_original);
    FN_variations   = fieldnames(data_variations);
    N_subplots      = numel(FN_variations) / numel(FN_original);
    
    % Create figure from random generated trajectory
    i_figures       = randperm(numel(FN_original), N_plots);

    % Create actual figures
    for i = i_figures
        hFig = figure();
        set(hFig, 'Position', [100 100 figWidth figHeight])
        set(gcf,'Color','white');
        
        hFig2 = figure();
        set(hFig2, 'Position', [100 100 figWidth figHeight])
        set(gcf,'Color','white');

        for j = 1 : N_subplots
            i_variation     = i + numel(FN_original) * (j-1);
            
            figure(hFig)
            sp1     = subplot(3,N_subplots,j);
            hold on; grid minor
            if ~strcmpi(type,'sampling_interval')
                plot(data_original.(FN_original{i}).timetab.Time, ...
                    data_original.(FN_original{i}).timetab.x,'LineWidth',1.5);
            end
            if strcmpi(type,'noise_FL') || strcmpi(type,'sampling_interval') 
                plot(data_variations.(FN_variations{i_variation}).timetab.Time, ...
                    data_variations.(FN_variations{i_variation}).timetab.x,'LineWidth',1.5);
            end
            
            plot(data_variations.(FN_variations{i_variation}).timetab.Time( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)), ...
                data_variations.(FN_variations{i_variation}).timetab.x( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)),'*');
            
            title(char(strcat(type,{' - '},labels(i_variation))),'Interpreter', 'none'); 
            ylabel('Position, m','FontSize',sFont,'FontWeight','normal');
            if strcmpi(type,'noise_FL')
                legend('$$x_i$$','$$x_{i,noisy}$$','Reset','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            else
                legend('$$x_i$$','Reset','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            end
            set(gca,'FontSize',sFont)
            
            sp2     = subplot(3,N_subplots,j+N_subplots);
            hold on; grid minor
            if ~strcmpi(type,'sampling_interval')
                plot(data_original.(FN_original{i}).timetab.Time, ...
                    data_original.(FN_original{i}).timetab.v,'LineWidth',1.5);
            end
            
            if strcmpi(type,'noise_FL') || strcmpi(type,'sampling_interval')
                plot(data_variations.(FN_variations{i_variation}).timetab.Time, ...
                    data_variations.(FN_variations{i_variation}).timetab.v,'LineWidth',1.5);
            end
            
            plot(data_variations.(FN_variations{i_variation}).timetab.Time( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)), ...
                data_variations.(FN_variations{i_variation}).timetab.v( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)),'*');
            
            title(' '); 
            ylabel('Speed, m/s','FontSize',sFont,'FontWeight','normal');
            if strcmpi(type,'noise_FL')
                legend('$$v_i$$','$$v_{i,noisy}$$','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            else
                legend('$$v_i$$','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            end
            set(gca,'FontSize',sFont)
            
            sp3     = subplot(3,N_subplots,j+(2*N_subplots));
            hold on; grid minor
            if ~strcmpi(type,'sampling_interval')
                plot(data_original.(FN_original{i}).timetab.Time, ...
                    data_original.(FN_original{i}).timetab.a,'LineWidth',1.5);
            end
            
            if strcmpi(type,'noise_FL') || strcmpi(type,'sampling_interval') 
                plot(data_variations.(FN_variations{i_variation}).timetab.Time, ...
                    data_variations.(FN_variations{i_variation}).timetab.a,'LineWidth',1.5);
            end
            
            plot(data_variations.(FN_variations{i_variation}).timetab.Time( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)), ...
                data_variations.(FN_variations{i_variation}).timetab.a( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)),'*');
            
            title(' '); 
            ylabel('Acceleration, m/s^2','FontSize',sFont,'FontWeight','normal');
            if strcmpi(type,'noise_FL')
                legend('$$a_i$$','$$a_{i,noisy}$$','Reset','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            else
                legend('$$a_i$$','Reset','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            end
            set(gca,'FontSize',sFont)
            
            linkaxes([sp1 sp2 sp3], 'x')
            
            %% 
            figure(hFig2)
            sp1    = subplot(2,N_subplots,j);
            hold on; grid minor
            if ~strcmpi(type,'sampling_interval')
                plot(data_original.(FN_original{i}).timetab.Time, ...
                    data_original.(FN_original{i}).timetab.s,'LineWidth',1.5);
            end
            
            if strcmpi(type,'noise_FL') || strcmpi(type,'noise_L') || strcmpi(type,'sampling_interval')
                plot(data_variations.(FN_variations{i_variation}).timetab.Time, ...
                    data_variations.(FN_variations{i_variation}).timetab.s,'LineWidth',1.5);
            end
            
            plot(data_variations.(FN_variations{i_variation}).timetab.Time( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)), ...
                data_variations.(FN_variations{i_variation}).timetab.s( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)),'*');
            
            title(' '); 
            ylabel('Distance-gap, m','FontSize',sFont,'FontWeight','normal');
            if strcmpi(type,'noise_FL') || strcmpi(type,'noise_L')
                legend('$$s_{i}$$','$$s_{i,noisy}$$','Reset','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            else
                legend('$$s_{i}$$','Reset','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            end
            set(gca,'FontSize',sFont)
            
            sp2     = subplot(2,N_subplots,j+N_subplots);
            hold on; grid minor
            if ~strcmpi(type,'sampling_interval')
                plot(data_original.(FN_original{i}).timetab.Time, ...
                    data_original.(FN_original{i}).timetab.vl,'LineWidth',1.5);
            end
            
            if strcmpi(type,'noise_FL') || strcmpi(type,'noise_L') || strcmpi(type,'sampling_interval')
                plot(data_variations.(FN_variations{i_variation}).timetab.Time, ...
                    data_variations.(FN_variations{i_variation}).timetab.vl,'LineWidth',1.5);
            end
            
            plot(data_variations.(FN_variations{i_variation}).timetab.Time( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)), ...
                data_variations.(FN_variations{i_variation}).timetab.vl( ...
                find(data_variations.(FN_variations{i_variation}).timetab.reset)),'*');
            
            title(' '); 
            ylabel('Velocity lead-vehicle, m/s','FontSize',sFont,'FontWeight','normal');
            if strcmpi(type,'noise_FL') || strcmpi(type,'noise_L')
                legend('$$v_{i-1}$$','$$v_{i-1,noisy}$$','Reset','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            else
                legend('$$v_{i-1}$$','Reset','Interpreter','Latex', ...
                    'Orientation','Horizontal','Location','North')
            end
            set(gca,'FontSize',sFont)
            
            linkaxes([sp1 sp2], 'x')
            
            
        end
        
    end

end






