function    [validation_table, p_IDM] = cross_validate_IDM(data_in, varargin)
    global options calibration_setup dt_data
    global p_IDM_pub
    global a_range b_range T_range v0_range s0_range
    
    % Change calibration_setup to desired setup
    tmp_calibration_setup   = calibration_setup;
    if numel(varargin) > 0
        for i = 1 : 2 : numel(varargin)
            tmp_calibration_setup.(varargin{i})     = varargin{i+1};
        end
    end

    %% Perform actual validation 
    
    % Initiate some stuff ...
    N_param    	= numel(p_IDM_pub);
    FN          = fieldnames(data_in);
    k_folds     = NaN(numel(FN),1);
    tmp_err     = [];
    
    % Find validation reset indices
    data_w_reset    = find_validation_reset_points(data_in);
    
    progressbar(0,0)
    for i = 1 : numel(FN)
        progressbar([],0)
        
        % Find all folds for calibration / validation
        idx_reset   = [find( ...
            data_w_reset.(FN{i}).timetab.reset .* ...
            max(strcmpi(data_w_reset.(FN{i}).timetab.reset_type, 'hard'), ...
            strcmpi(data_w_reset.(FN{i}).timetab.reset_type, 'vali'))); ...
            size(data_w_reset.(FN{i}).timetab.reset,1)];
        tmp_fold_idxs   = find(diff(idx_reset) == calibration_setup.t_reset/dt_data);
        fold_idxs       = [idx_reset(tmp_fold_idxs) idx_reset(tmp_fold_idxs + 1) - 1];
        k_folds(i)      = size(fold_idxs,1);
        
        % Hold out each fold once for validation
        idx_all         = 1 : size(data_in.(FN{i}).timetab,1);
        for j = 1 : k_folds(i)
            % Get calibration and validation data
            data_curr   = data_in.(FN{i}).timetab;
            i_vali      = fold_idxs(j,1) : fold_idxs(j,2);
            data_vali   = data_curr(i_vali,:);
            
            % Make sure each trajectory is initiated correctly.
            data_vali.reset(1)          = 1;
            data_vali.reset_type{1}     = {'hard'};
            i_cali      = idx_all(~ismember(idx_all,i_vali));
            if i_vali(end) < size(data_curr,1)
               data_curr.reset(i_vali(end) + 1)         = 1; 
               data_curr.reset_type{i_vali(end) + 1}    = {'hard'}; 
            end
            data_cali   = data_curr(i_cali,:);
            
            % Perform calibration on non-holdout data
            progressbar((i-1)/numel(FN), (j-1)/k_folds(i))
            fun_IDM     = @(p_IDM) obj_fun_IDM(p_IDM, ...
                data_cali.x, ...
                data_cali.v, ...
                data_cali.xl, ...
                data_cali.vl, ...
                data_cali.s, ...
                data_cali.reset, ...
                data_in.(FN{i}).calibration_setup);

            A           = [];
            b           = [];
            Aeq         = [];
            beq         = [];
            %             [a, b, T, v0, s0]
            lb          = [a_range(1),  b_range(1),  T_range(1),  v0_range(1),  s0_range(1)] .* 1e-4;
            ub          = [8.0,  8.0,  10,  250/3.6,  10];
            nonlcon     = [];

            % Run calibration
            [p_IDM(i,:,j), ~, exitflag(i,j), ~] = ...
                fmincon(fun_IDM,p_IDM_pub,A,b,Aeq,beq,lb,ub,nonlcon,options);

            % Validate the model using the obtained calibration parameters
            [~, ~, ~, ~, tmp_err(i,j)] = ...
                get_model_trajectories_IDM(true, ...
                    p_IDM(i,:,j), ...
                    data_vali.x, ...
                    data_vali.v, ...
                    data_vali.xl, ...
                    data_vali.vl, ...
                    data_vali.s, ...
                    data_vali.reset, ...
                    data_vali.reset_type, ...                        
                    tmp_calibration_setup);

            if ~ismember(exitflag(i,j), [0, 1, 2])
                p_IDM(i,:,j)    = NaN(1,N_param);
                tmp_err(i,j)    = NaN;
            end
        end
    end
    progressbar(1,1)
    
    % Make note of failed calibration
    nanvals         = isnan(tmp_err);
    folds_failed    = sum(nanvals,2);
    
    % Set non-existing folds to NaN
    for i = 1 : size(k_folds,1)
        tmp_err(i,k_folds(i)+1:end) = NaN;
    end
    
    % Compute mu and sigma and return
    mu      = nanmean(tmp_err,2);
    sigma   = nanstd(tmp_err,0,2);
    
    % Create validation table
    validation_table = table(FN, repmat({'IDM'},[numel(FN),1]), ...
        repmat(char(strcat(tmp_calibration_setup.error_measure,'_',...
        tmp_calibration_setup.calibration_variable)),[numel(FN),1]), k_folds, ...
        mu,sigma,folds_failed, 'VariableNames',...
        {'Trajectory','CalibrationModel','ValidationType', ...
        'NumberOfFolds','Mean','Std','NumberFailed'});
end

    
    
    
    
    
    
    