%% Program is written to read in the raw data from the SAE-L2 platoontest day

% Script written by:    Mathieu Blauw
% Date:                 
% Institution:          Delft University of Technology

%% Clear variables and add functions to current path
clear all
addpath('./00_function_files_exchange/progressbar')                    % https://nl.mathworks.com/matlabcentral/fileexchange/6922-progressbar

%% Scan directories for files ...
% Scan for vehicle directories
folder      = 'E:\Graduation\SAE-L2\Platoontest\data\Demorit 13-06-2018\';
subfolders  = dir(folder);

% Scan within vehicle directories for desired folders
dir_list    = {'Advantech_GPS', ...
                    'Advantech_IVCP', ...
                    'Advantech_MobilEye', ...
                    'Advantech_VCIL_'};

% Define list of vehicles
veh_list    = {'Tesla', 'Audi', 'Mercedes 1', 'Mercedes 2', ...
                    'BMW 1', 'BMW 2', 'BMW 3'};

% Remove parent directories (. and ..)
subfolders  = subfolders(~ismember({subfolders.name},{'..','.'})); 

% Create empty struct to store timetables consisting of vehicle data
tab_all 	= struct();
file_err    = {};
file_empt   = {};           % Empty file
file_empt2  = {};           % Only time logged 

% Initiate progressbar
progressbar(0,0,0)
progressbar('Vehicles','Directories','Files')

% Load files
for i = 1 : numel(subfolders)
    progressbar([],0)
    progressbar(i/numel(subfolders)-0.001)
    % i = ...
    %   ... 1 - Tesla
    %   ... 2 - Audi
    %   ... 3 - Mercedes
    %   ... 4 - Mercedes
    %   ... 5 - BMW  
    %   ... 6 - BMW  
    %   ... 7 - BMW  
    
    dir_all     = {};

    dir_curr    = fullfile(subfolders(i).folder, ...
        subfolders(i).name);
    dir_child   = dir(dir_curr);
    
    keep        = zeros(1,numel(dir_child));
    for j = 1 : numel(dir_list)
        keep    = keep + strncmpi(dir_list(j),{dir_child.name},numel(dir_list{j}));
    end
    dir_child(keep==0)  = [];
    
    dir_all(end+1 : end+numel(dir_child),1)     = fullfile(dir_curr,{dir_child.name});
    dir_all(end-numel(dir_child)+1 : end,2)     = {dir_child.name};

    for j = 1 : length(dir_all)
        progressbar([],[],0)
        progressbar([],j/numel(dir_all)-0.001)
        % j = ...
        %   ... 1 - GPS
        %   ... 2 - IVCP
        %   ... 3 - MobilEye
        %   ... 4 - VCIL Vehicle
        %   ... 5 - VCIL To MobilEye
        
        % List all .csv files
        files_dir   = dir(dir_all{j});

        foi         = {};
        for k = 1 : numel(files_dir)
            ext   = strsplit(files_dir(k).name,'.');
            if strcmp(char(ext(numel(ext))),'csv')
                foi{end+1,1}    = fullfile(files_dir(k).folder,files_dir(k).name);
            end
        end
        
        % Re-initiate (and clear) tab_full
        tab_full    = struct();

        for k = 1 : numel(foi)
            progressbar([],[],k/numel(foi))

            opts        = detectImportOptions(foi{k},'NumHeaderLines',0);
            opts.ExtraColumnsRule = 'ignore';

            % Correct wrongly detected variables ..
            vars_wrong = {'gearstick_position', 'gearstick_position_raw', ...
                'button', 'button_raw'};
            opts.VariableTypes(ismember(opts.VariableNames,vars_wrong)) = {'double'};

            tab         = readtable(foi{k},opts);

            % Break if file is empty
            if size(tab,1) > 0 && size(tab,2) > 4
                
                timestamp   = datetime((tab.logtime + tab.midnight)/1000,...
                    'convertfrom','posixtime', ...
                    'Format','dd-MM-yyyy HH:mm:ss.SSS');
                timestamp2  = datetime((tab.synctime + tab.midnight)/1000,...
                    'convertfrom','posixtime', ...
                    'Format','dd-MM-yyyy HH:mm:ss.SSS');
                tab.Time2   = timestamp2;

                % GPS data
                %   GPRMC - Recommended minimum specific GPS/Transit data
                %   GPVTG - Track made good and ground speed
                %   GPGGA - Global Positioning System Fix Data
                %   GPGSA - GPS DOP and active satellites 
                %   GPGLL - Geographic position, latitude / longitude

                time_tab    = table2timetable(tab,'RowTimes',timestamp);
                keys_new    = time_tab.Properties.VariableNames;
                keys_del    = {'logtime','midnight','synctime', ...
                                'GPRMC','GPVTG','GPGGA','GPGSA','GPGLL', ...
                                keys_new{strncmpi(keys_new,'Var',3)}};

                % Delete unnecessary table information
                time_tab    = removevars(time_tab, ...
                        keys_del(ismember(keys_del,time_tab.Properties.VariableNames)));

                foi_type    = regexp(foi{k},'\[(?:.(?!\[))+$');
                foi_type    = matlab.lang.makeValidName(foi{k}(foi_type+1:end-5));

                if ~ sum(ismember(fieldnames(tab_full), foi_type))
                    tab_full.(foi_type)	= time_tab;
                else
                    keys_new    = time_tab.Properties.VariableNames;
                    keys_curr   = tab_full.(foi_type).Properties.VariableNames;
                    keys_add    = ismember(keys_curr,keys_new);

                    keys_same   = {'Time'};
                    keys_same(end+1 : end+numel(keys_curr(keys_add)),1) ...
                                = keys_curr(keys_add);

                    % Outer join
                    tab_full.(foi_type)    = outerjoin(tab_full.(foi_type), ...
                        time_tab, ...
                        'Keys',keys_same, ...
                        'MergeKeys',true);
                end
                
            else
                if size(tab,1) == 0
                    file_empt{end+1,1} = foi{k};
                else
                    file_empt2{end+1,1} = foi{k};
                end
            end
        end
        
        % Write to final table
        try
            tab_all.(erase(subfolders(i).name,'-')).(char((dir_all(j,2)))) = tab_full;
        catch
            fprintf('...')
        end
    end
end
progressbar(1)













