% Program is written to compare logged accelerations and velocities

clearvars -except tab_all
addpath('./00_function_files_exchange/lonlat_to_km')                    % https://nl.mathworks.com/matlabcentral/fileexchange/38812-latlon-distance
addpath('./00_function_files_exchange/progressbar')                     % https://nl.mathworks.com/matlabcentral/fileexchange/6922-progressbar
addpath('./00_function_files_pre_analysis')
addpath('./00_function_files_synthetic_real')

%% Load data if not already existing ... 
if ~exist('tab_all','Var')
    tic
    load(fullfile('E:\Graduation\SAE-L2\Matlab','data_audi.mat'))
    t_load  = toc;
    fprintf(char(strcat({'Loaded data in '},num2str(t_load),{' seconds.\n'})))
else
    fprintf('Data already loaded. Continue without loading ...\n')
end
if ~exist('lags','Var')
    load(fullfile('../a2. output','lags_with_correction_v3.mat'))
end

%% Initiate ...

% ... figure properties
cmap    = colormap(lines(7));

% ... constants
g       = 9.80665;
Fs      = 10;

%% Select data

% Define times to select
t_start     = datetime([2018 06 13 00 00 00]);
t_end       = datetime([2018 06 14 00 00 00]);

% Select data
GPS         = select_GPS(tab_all,lags,t_start,t_end,Fs);
CAN         = select_CAN(tab_all,t_start,t_end,Fs);

% Only keep common times
[~,ia,ib]   = intersect(GPS.Time,CAN.Time);
GPS         = GPS(ia,:);
CAN         = CAN(ib,:);

%% Find least-squares solution by rewriting problem as ARX model
%   Y       = A    * X          + E
%   V_GPS   = V_OD * delta_k    + E -> min_X E'E

Y           = GPS.speed;
A           = CAN.vehicle_speed;
X           = (A'*A)\A'*Y;

% Compute percentage deviation of CAN-bus velocity signal
delta_k     = 1 - X;

% Plot differences

try
    close(hFig)
end

sFont = 14;
hFig = figure();
set(hFig, 'Position', [100 100 1400 800])
set(gcf,'Color','white');

% Add plots to figure
sp1 = subplot(1,1,1);
hold on;
plot(GPS.Time,GPS.speed,'LineWidth',1.5)
plot(CAN.Time,CAN.vehicle_speed,'LineWidth',1.5)
plot(CAN.Time,CAN.vehicle_speed * (1-delta_k),'LineWidth',1.5)

% Set figure properties
legend('GPS (w/lag compensation)','CAN','CAN (adjusted)');
grid minor
ylabel('Speed, m/s','FontSize',sFont,'FontWeight','normal');     
xlabel('Time','FontSize',sFont,'FontWeight','normal');     
set(gca,'FontSize',sFont)
title('CAN-bus bias compensation'); 


















